__version__ = "0.0.9"

from .anyline import AnylineDetector
from .canny import CannyDetector
from .dwpose import DWposeDetector
from .hed import HEDdetector
from .leres import LeresDetector
from .lineart import LineartDetector
from .lineart_anime import LineartAnimeDetector
from .lineart_standard import LineartStandardDetector
from .mediapipe_face import MediapipeFaceDetector
from .midas import MidasDetector
from .mlsd import MLSDdetector
from .normalbae import NormalBaeDetector
from .open_pose import OpenposeDetector
from .pidi import PidiNetDetector
from .segment_anything import SamDetector
from .shuffle import ContentShuffleDetector
from .teed import TEEDdetector
from .zoe import ZoeDetector
